Calculate the duration of a code for a datavyu column

calc_duration(column = NULL, code = NULL, directory = NULL, by_file = FALSE)

Arguments

column

the column as a character string

code

the code as a character string

directory

the path to the directory as a character string

by_file

whether or not to calculate the frequencies by file (logical)

Value

A data frame generated with the janitor package