Plot code frequency for a datavyu column

plot_time_series(
  columns,
  directory = NULL,
  colors = 1,
  cat_order = NULL,
  color_scale = NULL
)

Arguments

columns

the column or columns to select as character string or vector

directory

path to where csv files are to be found with datavyur::import_datavyu()

colors

color palette to use, options from ggplot2::scale_color_brewer() function

cat_order

character vector of the order in which to display codes in plot

color_scale

a named character vector manually specifying a color scale will also reorder based on order provided

Value

A ggplot2 plot