Summarize a datavyu column

summarize_column(
  column,
  code,
  directory = NULL,
  by_file = FALSE,
  summary = "frequency"
)

Arguments

column

the column as a character string

code

the code as a character string

directory

the path to the directory as a character string; can be set with options(directory = "")

by_file

whether or not to calculate the frequencies by file (logical)

summary

either "frequency" or "duration"

Value

A data frame generated with the janitor package

Examples

if (FALSE) { summarize_column(column = "childhands", code = "childhands.hand", directory = "ex-data/datavyu_output_11-16-2020_13-26") summarize_column(column = "childhands", code = "childhands.hand", directory = "ex-data/datavyu_output_11-16-2020_13-26", by_file = TRUE) summarize_column(column = "childhands", code = "childhands.hand", directory = "ex-data/datavyu_output_11-16-2020_13-26", by_file = TRUE, summary = "duration") }