Calculate code frequencies for a datavu column
calc_frequencies(column, code, directory = NULL, by_file = FALSE)
| column | the column as a character string |
|---|---|
| code | the code as a character string |
| directory | the path to the directory as a character string |
| by_file | whether or not to calculate the frequencies by file (logical) |
A data frame generated with the janitor package